@@ -1,14 +1,19 @@
+#  You may distribute under the terms of either the GNU General Public License
+#  or the Artistic License (the same terms as Perl itself)
+#
+#  (C) Paul Evans, 2009,2010 -- leonerd@leonerd.org.uk
+
 package Convert::Color::Library;
 
 use strict;
 use warnings;
 use base qw( Convert::Color::RGB8 );
 
-use constant COLOR_SPACE => 'lib';
+__PACKAGE__->register_color_space( 'lib' );
 
 use Carp;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 =head1 NAME
 
